/// <reference types="emscripten" />
import { Logger } from './logger.js';
export { WorkerMain } from './worker/WorkerMain.js';
export { Anchor, Color, ColorJSON, Direction, JSONType, MarginsWithUnit, MarginsWithUnitJSON, MeasureUnit, NumberWithUnit, NumberWithUnitJSON, Orientation, Point, PointJSON, PointWithUnit, PointWithUnitJSON, Quadrilateral, QuadrilateralJSON, Rect, RectJSON, RectWithUnit, RectWithUnitJSON, Size, SizeJSON, SizeWithAspect, SizeWithUnit, SizeWithUnitAndAspect, SizeWithUnitAndAspectJSON, SizeWithUnitJSON, SizingMode } from './Common.js';
import { D as DataCaptureLoader } from './Camera-Cz-HPV-7.js';
export { g as Camera, m as CameraAccess, e as CameraJSON, C as CameraPosition, l as CameraSettings, i as CameraSettingsFromJSON, j as CameraSettingsJSON, h as CameraSettingsJSONBase, o as Change, H as ContextStatus, G as ContextStatusJSON, u as DataCaptureComponent, t as DataCaptureComponentJSON, B as DataCaptureContext, x as DataCaptureContextCreationOptions, y as DataCaptureContextJSON, E as DataCaptureContextListener, S as DataCaptureLoaderOptions, q as DataCaptureMode, r as DataCaptureModeJSON, J as DataCaptureOverlay, M as DataCaptureView, L as DataCaptureViewJSON, K as DataCaptureViewListener, n as DeviceCamera, F as FocusGestureStrategy, N as FrameData, a as FrameSource, d as FrameSourceJSON, c as FrameSourceListener, b as FrameSourceState, R as OverrideState, P as PrivateChangeSet, s as PrivateDataCaptureComponent, w as PrivateDataCaptureContext, v as PrivateDataCaptureContextOptions, p as PrivateDataCaptureMode, A as PrivateFrameHandler, z as PrivateFrameHandlerResponse, O as PrivateLoadableFrameData, I as PrivateMirrorAxis, T as TorchState, f as VideoFrameResolution, V as VideoResolution, Q as convertToPublicFrameData, k as isCameraFrameSource } from './Camera-Cz-HPV-7.js';
export { LoadingStatus, LoadingStatusSubscriber, ProgressInfo, default as loadingStatus } from './LoadingStatus.js';
export { DeepMutable, DeepPartial, DistributiveKeyOf, MethodSignature, Mutable, Optional, Prettify, assert, assertUnreachable, assertUnreachableThrowException } from './tsHelper.js';
export { AnchorPositions, AnchorPositionsJSON } from './private/AnchorPositions.js';
export { BrowserHelper } from './browserHelper.js';
export { BrowserCompatibility, Feature } from './browserCompatibility.js';
export { DataCaptureContextSettings, DataCaptureContextSettingsJSON } from './DataCaptureContextSettings.js';
export { DataCaptureVersion } from './DataCaptureVersion.js';
export { FocusGesture, FocusGestureJSON, LogoStyle, SwipeToZoom, TapToFocus, ZoomGesture, ZoomGestureJSON } from './DataCaptureViewPlusRelated.js';
export { Feedback, FeedbackJSON, Sound, SoundJSON, Vibration, VibrationJSON } from './Feedback.js';
export { ImageFrameSource, ImageFrameSourceJSON } from './ImageFrameSource.js';
export { Localization } from './Localization.js';
export { LocationSelection, LocationSelectionJSON, PrivateNoneLocationSelection, RadiusLocationSelection, RectangularLocationSelection } from './LocationSelection.js';
export { Translations } from './translations.js';
export { SingleImageUploader, SingleImageUploaderJSON, SingleImageUploaderType } from './SingleImageUploader.js';
export { SingleImageUploaderSettings, SingleImageUploaderSettingsJSON } from './SingleImageUploaderSettings.js';
export { CameraFOVSwitchControl, CameraSwitchControl, Control, TorchSwitchControl } from './ViewControls.js';
export { NoViewfinder, Viewfinder } from './Viewfinder.js';
export { AimerViewfinderJSON, LaserlineViewfinderStyle, LaserlineViewfinderStyleJSON, PrivateLaserlineViewfinderDefault, PrivateRectangularViewfinderAnimation, PrivateRectangularViewfinderDefault, RectangularViewfinderAnimation, RectangularViewfinderJSON, RectangularViewfinderLineStyle, RectangularViewfinderStyle, ViewfinderJSON, ViewfinderType, ViewfinderTypeAimer, ViewfinderTypeLaserLine, ViewfinderTypeNone, ViewfinderTypeRectangular, ViewfinderTypeTargetAimer } from './ViewfinderPlusRelated.js';
export { LaserlineViewfinder } from './LaserlineViewfinder.js';
export { RectangularViewfinder } from './RectangularViewfinder.js';
export { AimerViewfinder } from './AimerViewfinder.js';
export { Brush, BrushJSON } from './Brush.js';
export { DataCaptureError, DataCaptureErrorDetails } from './DataCaptureError.js';
export { Deferred } from './private/utils/deferred.js';
export { debounce } from './private/utils/debounce.js';
export { isObject } from './private/utils/isObject.js';
export { Handler, Match, Predicate, match } from './private/utils/match.js';
export { unknownErrorToString } from './private/utils/unknownErrorToString.js';
export { Timeout } from './private/utils/timeout.js';
export { defineCustomElements } from './private/utils/defineCustomElements.js';
export { css } from './private/utils/css.js';
export { html } from './private/utils/html.js';
export { waitTransitionEndForElement } from './private/utils/waitTransitionEndForElement.js';
export { wait } from './private/utils/wait.js';
export { ScanditHTMLElement } from './private/utils/ScanditHTMLElement.js';
export { isWorkerScope } from './private/utils/isWorkerScope.js';
export { throttle } from './private/utils/throttle.js';
import './private/Serializable.js';
import './private/FrameReaders/WatermarkStack.js';
import './private/CustomLocationsView.js';
import './private/View.js';
import './private/HtmlElementState.js';
import 'csstype';

type PrivateCaptureModuleName = "BarcodeCapture" | "IdCapture" | "Parser";
interface ModuleLoader {
    moduleName: string;
    load(options: ConfigureOptions): Promise<any>;
}
interface ConfigureOptions {
    licenseKey: string;
    libraryLocation: string;
    moduleLoaders: ModuleLoader[];
    logLevel?: Logger.Level;
    licenseDataPath?: string;
}
/**
 * @hidden
 *
 * Used by tests.
 */
declare function resetConfigure(): Promise<void>;
declare function configure(options: ConfigureOptions): Promise<void>;
/**
 * @hidden
 *
 * Used by tests.
 */
declare function setMainDataCaptureLoader(newLoader: DataCaptureLoader): void;

export { type ConfigureOptions, DataCaptureLoader, Logger, type ModuleLoader, type PrivateCaptureModuleName, configure, resetConfigure, setMainDataCaptureLoader };
